Package: metabom8
Type: Package
Title: A High-Performance R Package for Metabolomics Modeling and
        Analysis
Version: 1.1.0
Authors@R: person(given = "Torben",
            family = "Kimhofer",
            role = c("aut", "cre"),
            email = "tkimhofer@gmail.com",
            comment = c(ORCID = "0000-0001-7158-9930"))
Description: Tools for 1D NMR metabolomics workflows, including import and 
              preprocessing of Bruker experiments, multivariate modeling (PCA, PLS, OPLS)
              and model analytics and validation (y-permutations, cv-anova). Performance-critical 
              routines are implemented in C++ and use the Armadillo and Eigen linear algebra 
              libraries to improve runtime.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.6.0)
Imports: abind, colorRamps, ellipse, fs, ggplot2, ggrepel, graphics,
        methods, parallel, pcaMethods, plotly, pROC, progress, ptw,
        Rcpp (>= 1.0.4.6), reshape2, rlang, scales, signal, stats,
        utils
LinkingTo: Rcpp, RcppArmadillo, RcppEigen
biocViews: Metabolomics, Cheminformatics, Preprocessing, DataImport,
        Alignment, WorkflowStep
BugReports: https://github.com/tkimhofer/metabom8/issues
URL: https://tkimhofer.github.io/metabom8/
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
Suggests: BiocStyle, dplyr, DT, ExperimentHub, htmlTable, knitr,
        rmarkdown, testthat
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/metabom8
git_branch: devel
git_last_commit: 977c8fa
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 23:39:47 UTC; biocbuild
Author: Torben Kimhofer [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7158-9930>)
Maintainer: Torben Kimhofer <tkimhofer@gmail.com>
