# Generated by roxygen2: do not edit by hand

S3method(plot,m8_stocsy1d)
S3method(print,m8_stocsy1d)
export(add_note)
export(align_segment)
export(align_spectra)
export(balanced_boot)
export(balanced_mc)
export(binning)
export(bline)
export(calibrate)
export(cliffs_d)
export(correct_baseline)
export(correct_lw)
export(cv_anova)
export(dmodx)
export(ellipse2d)
export(es_cdelta)
export(excise)
export(fitted)
export(get.idx)
export(get_idx)
export(get_provenance)
export(hotellingsT2)
export(kfold)
export(list_preprocessing)
export(lw)
export(matspec)
export(mc)
export(minmax)
export(noise_sd)
export(norm_eretic)
export(opls)
export(pareto_scaling)
export(pca)
export(plotStocsy)
export(plot_spec)
export(pls)
export(ppick)
export(ppick2)
export(pqn)
export(prep_X)
export(print_preprocessing)
export(print_provenance)
export(read1d)
export(read1d_proc)
export(read1d_raw)
export(scRange)
export(scores)
export(spec)
export(stocsy)
export(storm)
export(stratified_kfold)
export(unscaled)
export(uv_scaling)
export(vip)
export(weights)
export(xres)
exportClasses(m8_model)
exportMethods(loadings)
exportMethods(show)
exportMethods(summary)
import(methods)
importFrom(Rcpp,evalCpp)
importFrom(abind,abind)
importFrom(colorRamps,matlab.like2)
importFrom(ellipse,ellipse)
importFrom(fs,path_common)
importFrom(fs,path_rel)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_gradientn)
importFrom(ggplot2,scale_x_reverse)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(pROC,multiclass.roc)
importFrom(pROC,roc)
importFrom(parallel,detectCores)
importFrom(progress,progress_bar)
importFrom(ptw,asysm)
importFrom(reshape2,melt)
importFrom(rlang,.data)
importFrom(scales,breaks_pretty)
importFrom(signal,sgolayfilt)
importFrom(stats,aggregate)
importFrom(stats,approxfun)
importFrom(stats,ccf)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,pf)
importFrom(stats,pt)
importFrom(stats,qf)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,t.test)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(metabom8, .registration = TRUE)
