% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{covid_raw}
\alias{covid_raw}
\title{COVID-19 blood plasma proton NMR spectra (raw)}
\format{
A numeric matrix/data frame with 23 rows and 29,782 columns:
\describe{
\item{rows}{Spectra (samples)}
\item{columns}{Chemical shift variables in parts per million (ppm)}
}
}
\source{
Australian National Phenome Centre (ANPC), Murdoch University.
}
\description{
1D proton NMR spectra from SARS-CoV-2–positive patients (n = 10) and healthy controls (n = 13),
collected in a research study in Perth, Western Australia. Spectra are raw and require processing
before statistical analysis (see \code{?covid} for processed spectra).
}
\details{
FIDs were acquired using a Carr–Purcell–Meiboom–Gill (CPMG) pulse sequence on a 600 MHz Bruker
Avance II spectrometer using IVDr methods for blood plasma (300 K, 32 scans). The spectrometer was
equipped with a double-resonance broadband (BBI) probe and a refrigerated autosampler at
4\eqn{^{\circ}}C.
}
\examples{
data(covid_raw)
}
\references{
Kimhofer et al. (2020) \doi{10.1021/acs.jproteome.0c00280}
}
\keyword{datasets}
