% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stats_cv_sets_methods.R
\name{.kFold}
\alias{.kFold}
\title{k-fold cross-validation index generator}
\usage{
.kFold(k, Y)
}
\arguments{
\item{k}{Integer. Number of CV folds. If \code{k} is not valid or too high relative to number of rows in Y,
it defaults to leave-one-out CV (LOO-CV).}

\item{Y}{Matrix. Outcome matrix (observations x variables).}
}
\value{
A list of length \code{k}, where each element contains the training indices (integers)
for one CV fold.
}
\description{
Creates a list of training set indices for k-fold cross-validation (CV),
without considering class balance in Y. Each element of the list represents
the row indices used for training in one CV fold.
}
\keyword{internal}
