% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/preproc_alignSegment.R
\name{.dynamicIntervalsMedian}
\alias{.dynamicIntervalsMedian}
\title{Dynamic Interval Segmentation (RSPA-style)}
\usage{
.dynamicIntervalsMedian(X, ppm, half_win_ppm = 0.02, min_snr = 8)
}
\arguments{
\item{X}{Numeric matrix (spectra in rows).}

\item{ppm}{Numeric ppm vector.}

\item{half_win_ppm}{Numeric. Half window size around detected peaks.}
}
\value{
List of index vectors defining alignment intervals.
}
\description{
Defines peak-system intervals from the median spectrum for
recursive segment-wise alignment (RSPA).
}
\seealso{
Other NMR: 
\code{\link{get_idx}()}
}
\concept{NMR}
\keyword{internal}
