% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/preproc_alignSegment.R
\name{.shift_interp}
\alias{.shift_interp}
\title{Linear Interpolated Shift (Internal)}
\usage{
.shift_interp(x, lag, ppm = NULL)
}
\arguments{
\item{x}{Numeric vector.}

\item{lag}{Numeric scalar. Shift in index units. Positive values shift the
signal to the right, negative values shift to the left.}
}
\value{
Numeric vector of the same length as \code{x}.
}
\description{
Applies a linear shift to a numeric vector using interpolation.
Values outside the original domain are extended
using the boundary values (no zero padding).
}
\keyword{internal}
